#
# To run VASP this script calls $vasp_std
# (or posibly $vasp_gam and/or $vasp_ncl).
# These variables can be defined by sourcing vaspcmd
. vaspcmd 2> /dev/null

#
# When vaspcmd is not available and $vasp_std,
# $vasp_gam, and/or $vasp_ncl are not set as environment
# variables, you can specify them here
[ -z "`echo $vasp_std`" ] && vasp_std="mpirun -np 4 vasp"
[ -z "`echo $vasp_gam`" ] && vasp_gam="mpirun -np 4 vasp_g"
[ -z "`echo $vasp_ncl`" ] && vasp_ncl="mpirun -np 4 vasp_ncl"
#
# The real work starts here
#

#
# PBE ground state energy 
#
cp KPOINTS.BULK KPOINTS
rm WAVECAR
cp INCAR.DFT INCAR
$vasp_std
#
# increase number of bands
#
cp INCAR.DIAG INCAR
$vasp_std
cp OUTCAR OUTCAR.DIAG
cp WAVECAR WAVECAR.DIAG
cp WAVEDER WAVEDER.DIAG
cp CHGCAR CHGCAR.DIAG

#
# perform GW calculation based on PBE solution
#
cp INCAR.GW0 INCAR
$vasp_std
cp OUTCAR OUTCAR.GW0
cp WAVECAR WAVECAR.GW0 # store GW WAVECAR 

#
# calculate HSE ground state starting from PBE result
#
cp WAVECAR.DIAG WAVECAR
cp WAVEDER.DIAG WAVEDER
cp INCAR.HSE INCAR
$vasp_std
cp OUTCAR OUTCAR.HSE
cp WAVECAR WAVECAR.HSE

#------------------------------------------------------------------------
# post processing 
#------------------------------------------------------------------------
#
# interpolate PBE band structure with vasp
#
cp INCAR.BSTR INCAR
cp KPOINTS.BSTR KPOINTS  
cp WAVECAR.DIAG WAVECAR
cp CHGCAR.DIAG CHGCAR
$vasp_std
cp OUTCAR OUTCAR.BSTR
cp EIGENVAL EIGENVAL.BSTR
cp vasprun.xml vasprun.BSTR.xml
cp KPOINTS.BULK KPOINTS

for  i in "PBE" "GW0" "HSE" ; do 
   #
   # calculate decent DOS of PBE calculation
   #
   cp INCAR.DOS INCAR
   if [ "$i" == "PBE" ] ; then
     cp WAVECAR.DIAG WAVECAR
   else
     cp WAVECAR.$i WAVECAR
   fi
    
   $vasp_std
   cp vasprun.xml vasprun.$i.xml
   cp DOSCAR DOSCAR.$i
   #
   # interpolate PBE band structure with wannier90
   #
   cp INCAR.WAN INCAR
   if [ "$i" == "PBE" ] ; then
     cp WAVECAR.DIAG WAVECAR
   else
     cp WAVECAR.$i WAVECAR
   fi
   cp wannier90.win.$i wannier90.win
   $vasp_std
   cp wannier90_band.dat wannier90_band.$i.dat
done
